@@ -9,7 +9,6 @@
 #' is set to \code{application/x-www-form-urlencoded}.
 #'
 #' @export
-#' @importFrom utils URLdecode
 #' @param query a url-encoded query string
 #' @examples q <- "foo=1%2B1%3D2&bar=yin%26yang"
 #' parse_query(q)
@@ -26,7 +25,7 @@ parse_query <- function(query){
   argslist <- sub("^&", "", regmatches(query, gregexpr("(^|&)[^=]+=[^&]+", query))[[1]])
   argslist <- strsplit(argslist, "=");
   values <- lapply(argslist, function(x){if(length(x) < 2) "" else paste(x[-1], collapse="=")});
-  values <- lapply(values, function(s) {URLdecode(chartr('+',' ',s))});
+  values <- lapply(values, function(s) {utils::URLdecode(chartr('+',' ',s))});
   names(values) <- lapply(argslist, "[[", 1);
   return(values)
 }
